@@ -64,24 +64,22 @@ class Client:
         url = urljoin(self.api_url, cohere.CHECK_API_KEY_URL)
         if use_xhr_client:
             response = self.__pyfetch(url, headers, None)
+            return response
         else:
             response = requests.request('POST', url, headers=headers)
         
         try:
-            if use_xhr_client:
-                res = json.loads(response)
-            else:
-                res = json.loads(response.text)
+            res = json.loads(response.text)
         except:
             raise CohereError(
                 message=response.text,
                 http_status=response.status_code,
                 headers=response.headers)
         if 'message' in res.keys(): # has errors
-                raise CohereError(
-                    message=res['message'],
-                    http_status=response.status_code,
-                    headers=response.headers)
+            raise CohereError(
+                message=res['message'],
+                http_status=response.status_code,
+                headers=response.headers)
         return res
 
     def generate(
@@ -180,8 +178,20 @@ class Client:
         req.open("POST", url, False)
         for key, value in headers.items():
             req.setRequestHeader(key, value)
-        req.send(json_body)
-        return req.response
+        try:
+            req.send(json_body)
+        except:
+            raise CohereError(
+                message=req.responseText,
+                http_status=req.status,
+                headers=req.getAllResponseHeaders())
+        res = json.loads(req.response)
+        if 'message' in res.keys():
+            raise CohereError(
+                message=res['message'],
+                http_status=req.status,
+                headers=req.getAllResponseHeaders())
+        return res
     
     def __request(self, json_body, endpoint, model) -> Any:
         headers = {
@@ -195,18 +205,7 @@ class Client:
         url = urljoin(self.api_url, model + '/' + endpoint)
         if use_xhr_client:
             response = self.__pyfetch(url, headers, json_body)
-            try:
-                res = json.loads(response)
-            except:
-                raise CohereError(
-                    message=res.text,
-                    http_status=res.status_code,
-                    headers=res.headers)
-            if 'message' in res.keys(): # has errors
-                raise CohereError(
-                    message=res['message'],
-                    http_status=res.status_code,
-                    headers=res.headers)
+            return res
         else:
             response = requests.request('POST', url, headers=headers, data=json_body)
             try:
